<?php
/*
 * 1. - Define constans
 */

define('THEMEROOT', get_stylesheet_directory_uri());
define('IMAGES', THEMEROOT . '/images');
define('SCRIPTS', THEMEROOT . '/js');

if ( ! isset( $content_width ) ) $content_width = 900;

/*
 * 2. - Set up theme Trends
 */

if (!function_exists('trends_setup')) {

    function trends_setup() {

        $lang_dir = THEMEROOT . '/languages';
        load_theme_textdomain('trends', $lang_dir);

        add_theme_support('post-formats', array(
            'gallery',
            'link',
            'image',
            'quote',
            'video',
            'audio'
                )
        );

        add_theme_support('automatic-feed-links');

        add_theme_support('post-thumbnails');

        register_nav_menus(
                array(
                    'main-menu' => __('Main Menu', 'trends')
                )
        );
    }

    add_action('after_setup_theme', 'trends_setup');
}

/*
 * 3. - Load scripts and stylesheets for the theme
 */

if (!function_exists('trends_scripts')) {

    function trends_scripts() {
        /*
         * Loading js scripts
         */
        wp_register_script('jquery', SCRIPTS . '/jquery.js');
        wp_register_script('semantic', THEMEROOT . '/css/semantic/semantic.min.js');
        wp_register_script('bxslider', SCRIPTS . '/jquery.bxslider.min.js');
        wp_register_script('custom', SCRIPTS . '/custom.js');

        wp_enqueue_script('jquery');
        wp_enqueue_script('semantic');
        wp_enqueue_script('bxslider');
        wp_enqueue_script('custom');


        /*
         * Load stylesheets
         */
        wp_enqueue_style('semantic', THEMEROOT . '/css/semantic/semantic.css');
        wp_enqueue_style('bxslider', THEMEROOT . '/css/jquery.bxslider.css');
    }

    add_action('wp_enqueue_scripts', 'trends_scripts');
}

/*
 * 4. - Register sidebars
 */

if (!function_exists('trends_widget_init')) {

    function trends_widget_init() {
        if (function_exists('register_sidebar')) {
            register_sidebar(
                    array(
                        'name' => __('Main Widget Area', 'trends'),
                        'id' => 'sidebar-1',
                        'description' => __('Appears on posts and pages.', 'trends'),
                        'before_widget' => '<div id="%1$s" class="widget %2$s">',
                        'after_widget' => '</div> <!-- end widget -->',
                        'before_title' => '<h5 class="widget-title ui block header">',
                        'after_title' => '</h5>',
                    )
            );

            register_sidebar(
                    array(
                        'name' => __('Footer Widget Area', 'trends'),
                        'id' => 'sidebar-2',
                        'description' => __('Appears on the footer.', 'trends'),
                        'before_widget' => '<div id="%1$s" class="widget four wide column %2$s">',
                        'after_widget' => '</div> <!-- end widget -->',
                        'before_title' => '<h5 class="widget-title">',
                        'after_title' => '</h5>',
                    )
            );
        }
    }

    add_action('widgets_init', 'trends_widget_init');
}

/*
 * 5. - Post meta header
 */
if (!function_exists('trends_post_meta_header')) {

    function trends_post_meta_header() {
        echo '<div class="ui horizontal list">';

        if (get_post_type() === 'post') {
            // If the post is sticky, mark it.
            if (is_sticky()) {
                echo '<div class="item"> ' . __('Sticky', 'trends') . ' </div>';
            }

            // Get the post author.
            printf(
                    '<div class="item ">  <a href="%1$s" rel="author"><i class="user icon"></i>%2$s </a> </div>', esc_url(get_author_posts_url(get_the_author_meta('ID'))), get_the_author()
            );

            // Get the date.
            echo '<div class="item"> <i class="icon calendar"></i>' . get_the_date() . ' </div>';
        }
    }

}

/*
 * 5. - Post meta footer
 */

if (!function_exists('trends_post_meta_footer')) {

    function trends_post_meta_footer() {
        echo '<div class="ui horizontal list">';

        if (get_post_type() === 'post') {

            // The categories.
            $category_list = get_the_category_list(', ');
            if ($category_list) {
                echo '<div class="item"> <i class="bookmark icon"></i>' . $category_list . ' </div>';
            }

            // The tags.
            $tag_list = get_the_tag_list('', ', ');
            if ($tag_list) {
                echo '<div class="item"> <i class="tags icon"></i> ' . $tag_list . ' </div>';
            }

            // Comments link.
            if (comments_open()) :
                echo '<div class="item">';
                echo '<span class="meta-reply">';
                echo '<i class="comments icon"></i>';
                comments_popup_link(__('Leave a comment', 'trends'), __('One comment so far', 'trends'), __('View all % comments', 'trends'));
                echo '</span>';
                echo '</div>';
            endif;

            // Edit link.
            if (is_user_logged_in()) {
                echo '<div class="item">';
                edit_post_link(__('Edit', 'trends'), '<span class="meta-edit"> <i class="edit icon"></i>', '</span>');
                echo '</div>';
            }
        }
    }

}

/*
 * 6. - Pagination 
 */

if (!function_exists('trends_paging_nav')) {

    function trends_paging_nav() {
        ?>
        <?php if (get_next_posts_link()) : ?>
            <div class="ui left labeled icon button">
                <i class="left arrow icon"></i>
                <?php next_posts_link(__(' Older Posts', 'trends')); ?>
            </div>
        <?php endif;
        ?>
        <?php if (get_previous_posts_link()) : ?>
            <div class="ui right labeled icon button">
                <i class="right arrow icon"></i>
                <?php previous_posts_link(__('Newer Posts ', 'trends')); ?>
            </div>
        <?php endif;
        ?>

        <?php
    }

}

/*
 * 7. - Render search form
 */

if (!function_exists('render_search_form')) {

    function render_search_form() {
        ?>
        <form role="search" method="get" class="search-form" action="<?php echo home_url('/'); ?>">
            <div class="ui icon input">
                <input placeholder="Search..." type="text" value="<?php echo get_search_query() ?>" name="s"/>
                <i class="search link icon"></i>
            </div>
        </form>
        <?php
    }

}
